@@ -12,6 +12,7 @@ class ReducedLatLonMapper(DatacubeMapper):
         self._axis_reversed = {mapped_axes[0]: False, mapped_axes[1]: False}
         self._first_axis_vals = self.first_axis_vals()
         self.compressed_grid_axes = [self._mapped_axes[1]]
+        self.md5_hash = md5_hash.get(resolution, None)
 
     def first_axis_vals(self):
         resolution = 180 / (self._resolution - 1)
@@ -1504,3 +1505,7 @@ class ReducedLatLonMapper(DatacubeMapper):
         second_idx = self.second_axis_vals(first_val).index(second_val)
         reduced_ll_index = self.axes_idx_to_reduced_ll_idx(first_idx, second_idx)
         return reduced_ll_index
+
+
+# md5 grid hash in form {resolution : hash}
+md5_hash = {}
