@@ -1,4 +1,8 @@
-class AxisOverdefinedError(KeyError):
+class PolytopeError(Exception):
+    pass
+
+
+class AxisOverdefinedError(PolytopeError, KeyError):
     def __init__(self, axis):
         self.axis = axis
         self.message = (
@@ -7,19 +11,19 @@ class AxisOverdefinedError(KeyError):
         )
 
 
-class AxisUnderdefinedError(KeyError):
+class AxisUnderdefinedError(PolytopeError, KeyError):
     def __init__(self, axis):
         self.axis = axis
         self.message = f"Axis {axis} is underdefined. It does not appear in any input polytope."
 
 
-class AxisNotFoundError(KeyError):
+class AxisNotFoundError(PolytopeError, KeyError):
     def __init__(self, axis):
         self.axis = axis
         self.message = f"Axis {axis} does not exist in the datacube."
 
 
-class UnsliceableShapeError(KeyError):
+class UnsliceableShapeError(PolytopeError, KeyError):
     def __init__(self, axis):
         self.axis = axis
         self.message = f"Higher-dimensional shape does not support unsliceable axis {axis.name}."
